@@ -15,8 +15,13 @@ import mns_common.utils.data_frame_util as data_frame_util
 import time
 from loguru import logger
 import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
+import mns_common.component.cache.cache_service as cache_service
+import mns_common.component.common_service_fun_api as common_service_fun_api
 
 mongodb_util = MongodbUtil('27017')
+
+REAL_TIME_DATA_KEY = "realtime_quotes_data_key"
+
 REAL_TIME_SCHEDULER_NAME = "realtime_quotes_now_sync"
 # 实时同步 bat
 REAL_TIME_TASK_NAME_PATH = 'H:\\real_time_task.bat'
@@ -76,7 +81,8 @@ def exist_sync_task():
         return True
 
 
-def check_data_sync_task_status():
+# 检查同步任务是否存在
+def check_data_sync_task_is_exist():
     now_date = datetime.datetime.now()
     if bool(is_data_sync_time(now_date)):
         if bool(1 - exist_sync_task()):
@@ -105,6 +111,30 @@ def is_data_sync_time(now_date):
     return is_trade_day and trade_time
 
 
+# 检查数据同步状态
+def sync_data_status_check(str_day):
+    col_name = db_name_constant.REAL_TIME_QUOTES_NOW + '_' + str_day
+    now_number = common_service_fun_api.realtime_quotes_now_max_number(col_name, 'number')
+
+    exist_number = cache_service.get_cache(REAL_TIME_DATA_KEY)
+    if exist_number is None:
+        # 设置缓存
+        cache_service.set_cache(REAL_TIME_DATA_KEY, now_number)
+    else:
+        # 缓存数据和现在数据一样同步任务未同步
+        if exist_number == now_number:
+            # 关闭现在同步任务 可能卡死了 只关闭 有定时任务会扫描到 重新打开
+            real_time_sync_task_close()
+            time.sleep(1)
+
+            # 设置缓存
+            cache_service.set_cache(REAL_TIME_DATA_KEY, now_number)
+        else:
+            # 设置缓存
+            cache_service.set_cache(REAL_TIME_DATA_KEY, now_number)
+
+
 if __name__ == '__main__':
+    while True:
+        sync_data_status_check('2025-08-05')
     # check_data_sync_task_status()
-    check_data_sync_task_status()
