@@ -194,4 +194,4 @@ STRATEGY_TOTAL_CHOOSE_PARAM = 'strategy_total_choose_param'
 # k 线参数表
 STRATEGY_K_LINE_PARAM = 'strategy_k_line_param'
 # 评分参数
-STRATEGY_SCORE_PARAM = 'strategy_k_line_param'
+STRATEGY_SCORE_PARAM = 'strategy_score_param'
