@@ -10,6 +10,13 @@ sys.path.append(project_path)
 
 EXTRA_INCOME = 'extraIncome'
 
+# us_stock 美股信息数据表
+US_STOCK = 'us_stock'
+# a股数据表
+A_STOCK = 'a_stock'
+# hk股票数据
+HK_STOCK = 'hk_stock'
+
 # 东方财富a股信息
 EM_A_STOCK_INFO = 'em_a_stock_info'
 
@@ -67,6 +74,10 @@ ONE_MINUTE_SYNC_FAIL = 'one_minute_sync_fail'
 
 US_STOCK_DAILY_QFQ_K_LINE = 'us_stock_daily_qfq_k_line'
 
+US_STOCK_DAILY_BFQ_K_LINE = 'us_stock_daily_bfq_k_line'
+
+US_STOCK_DAILY_HFQ_K_LINE = 'us_stock_daily_hfq_k_line'
+
 # us stock 1分钟集合数据
 US_STOCK_MINUTE_K_LINE_BFQ = 'us_stock_one_minute_k_line_bfq'
 
